@@ -19,8 +19,8 @@ import asyncio
 import logging
 import os
 import click
-from colors import color
 
+from bumble.colors import color
 from bumble.transport import open_transport_or_link
 from bumble.device import Device
 from bumble.utils import FlowControlAsyncPipe
